using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using MySql.Data.MySqlClient;
using System.IO;

namespace MySQLTimeStampTest {
	public partial class Form1 : Form {
		private MySqlConnection connection;
		FileInfo logFile;
		public Form1() {
			InitializeComponent();
			logFile = new FileInfo("log.txt");
			if (logFile.Exists)
				logFile.Delete();

			connection = new MySqlConnection();

			connection.StateChange += new StateChangeEventHandler(connection_StateChange);
		}

		private void log(string msg) {
			msg = "[" + DateTime.Now.ToString("H:mm.fff") + "]  " + msg;
			log_lb.Items.Add(msg);
			using (FileStream fs = new FileStream(logFile.FullName, FileMode.Append)) {
				StreamWriter writer = new StreamWriter(fs);
				writer.WriteLine(msg);
				writer.Flush();
			}
		}

		private void log(Exception e) {
			MessageBox.Show(e.GetType().ToString() + ":\n" + e.Message, "Exception", MessageBoxButtons.OK, MessageBoxIcon.Error);
			log(e.GetType().ToString() + ": " + e.Message);
		}

		private void connection_StateChange(object sender, StateChangeEventArgs e) {
			log("Changing connection state from " + e.OriginalState + " to " + e.CurrentState);

			if (e.CurrentState == ConnectionState.Open) {
				connect_btn.Text = "Disconnect";
				connect_btn.Enabled = true;
				info_pnl.Enabled = false;
				read_btn.Enabled = true;
			} else if (e.CurrentState == ConnectionState.Closed) {
				connect_btn.Text = "Connect";
				connect_btn.Enabled = true;
				info_pnl.Enabled = true;
				read_btn.Enabled = false;
			}
		}

		private void connect_btn_Click(object sender, EventArgs e) {
			connect_btn.Enabled = false;
			info_pnl.Enabled = false;

			if (connection.State == ConnectionState.Closed) {
				connect_btn.Text = "Connecting...";
				MySqlConnectionStringBuilder builder = new MySqlConnectionStringBuilder();
				builder.Server = host_tbx.Text;
				builder.UserID = user_tbx.Text;
				builder.Password = pass_tbx.Text;
				builder.Database = schema_tbx.Text;

				connection.ConnectionString = builder.ConnectionString;
				try {
					connection.Open();
				} catch (Exception ex) { log(ex); }
			} else if (connection.State == ConnectionState.Open) {
				connect_btn.Text = "Disconnecting...";
				connection.Close();
			}
		}

		private void read_btn_Click(object sender, EventArgs e) {
			try {
				log("Attempting to read from database...");
				MySqlCommand cmd = new MySqlCommand("SELECT * FROM `test`");
				cmd.Connection = connection;
				MySqlDataAdapter mda = new MySqlDataAdapter(cmd);
				DataTable ret = new DataTable();
				log("Filling DataTable...");
				mda.Fill(ret);
				log("Complete!");
			} catch (Exception ex) { log(ex); }
		}

	}
}